
# THIS FILE IS GENERATED FROM HIFIVE SETUP.PY
short_version = '1.4'
version = '1.4'
full_version = '1.4'
git_revision = '40b3e101b59f8f714bc28a5f4a9cd274f5b19419'
release = True

if not release:
    version = full_version
